@@ -9,7 +9,8 @@ from Cheetah.compat import PY2
 
 # Cheetah3 has already been taken at PyPI,
 # CheetahTemplate3 seems to be too long.
-name = 'Cheetah3'
+# CT3 is just right!
+name = 'CT3'
 description = "Cheetah is a template engine and code generation tool"
 license = "MIT"
 author = "Tavis Rudd"
@@ -40,7 +41,7 @@ packages = ['Cheetah',
             'Cheetah.Utils',
             ]
 classifiers = [line.strip() for line in '''\
-  Development Status :: 4 - Beta
+  Development Status :: 3 - Alpha
   Intended Audience :: Developers
   Intended Audience :: System Administrators
   License :: OSI Approved :: MIT License
@@ -56,6 +57,8 @@ classifiers = [line.strip() for line in '''\
   Programming Language :: Python :: 3.6
   Programming Language :: Python :: 3.7
   Programming Language :: Python :: 3.8
+  Programming Language :: Python :: 3.9
+  Programming Language :: Python :: 3.10
   Topic :: Internet :: WWW/HTTP
   Topic :: Internet :: WWW/HTTP :: Dynamic Content
   Topic :: Internet :: WWW/HTTP :: Site Management
